@@ -37,9 +37,11 @@ var(const Row<eT>& A, const u32 norm_type = 0)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "var(): given vector has no elements" );
+  const u32 A_n_elem = A.n_elem;
   
-  return op_var::direct_var(A.mem, A.n_elem, norm_type);
+  arma_debug_check( (A_n_elem == 0), "var(): given object has no elements" );
+  
+  return op_var::direct_var(A.mem, A_n_elem, norm_type);
   }
 
 
@@ -53,9 +55,11 @@ var(const Col<eT>& A, const u32 norm_type = 0)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "var(): given vector has no elements" );
+  const u32 A_n_elem = A.n_elem;
   
-  return op_var::direct_var(A.mem, A.n_elem, norm_type);
+  arma_debug_check( (A_n_elem == 0), "var(): given object has no elements" );
+  
+  return op_var::direct_var(A.mem, A_n_elem, norm_type);
   }
 
 
@@ -68,7 +72,7 @@ var(const subview_row<eT>& A, const u32 norm_type = 0)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "var(): given vector has no elements" );
+  arma_debug_check( (A.n_elem == 0), "var(): given object has no elements" );
   
   return op_var::direct_var(A, norm_type);
   }
@@ -83,9 +87,9 @@ var(const subview_col<eT>& A, const u32 norm_type = 0)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "var(): given vector has no elements" );
+  arma_debug_check( (A.n_elem == 0), "var(): given object has no elements" );
   
-  return op_var::direct_var(A, norm_type);
+  return op_var::direct_var(A.colptr(0), A.n_rows, norm_type);
   }
 
 
@@ -98,7 +102,7 @@ var(const diagview<eT>& A, const u32 norm_type = 0)
   {
   arma_extra_debug_sigprint();
   
-  arma_debug_check( (A.n_elem == 0), "var(): given vector has no elements" );
+  arma_debug_check( (A.n_elem == 0), "var(): given object has no elements" );
   
   return op_var::direct_var(A, norm_type);
   }
